@@ -1,5 +1,5 @@
 import pytest
-from nx_work_log.nx_work_log import MinuteTimer
+from nx_work_log.minute_timer import MinuteTimer
 
 
 @pytest.fixture()
